pyinstaller -n hello hello.py
ls -lh dist/hello
dist/hello/./hello

pyinstaller -n multiprocessing_test multiprocessing_test.py
ls -lh dist/multiprocessing_test
dist/multiprocessing_test/./multiprocessing_test
